@@ -427,8 +427,14 @@ def common_span_attributes(
     scope._span.set_attribute(SemanticConvention.GEN_AI_SYSTEM, gen_ai_system)
     scope._span.set_attribute(SemanticConvention.SERVER_ADDRESS, server_address)
     scope._span.set_attribute(SemanticConvention.SERVER_PORT, server_port)
-    scope._span.set_attribute(SemanticConvention.GEN_AI_REQUEST_MODEL, request_model)
-    scope._span.set_attribute(SemanticConvention.GEN_AI_RESPONSE_MODEL, response_model)
+    if request_model:
+        scope._span.set_attribute(
+            SemanticConvention.GEN_AI_REQUEST_MODEL, request_model
+        )
+    if response_model:
+        scope._span.set_attribute(
+            SemanticConvention.GEN_AI_RESPONSE_MODEL, response_model
+        )
     scope._span.set_attribute(DEPLOYMENT_ENVIRONMENT, environment)
     scope._span.set_attribute(SERVICE_NAME, application_name)
     scope._span.set_attribute(SemanticConvention.GEN_AI_REQUEST_IS_STREAM, is_stream)
