@@ -6,7 +6,8 @@ from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
 from wrapt import wrap_function_wrapper
 from openlit.instrumentation.agno.utils import (
     resolve_agno_knowledge_target,
-    resolve_agno_memory_target)
+    resolve_agno_memory_target,
+)
 from openlit.instrumentation.agno.agno import (
     agent_run_wrap,
     agent_continue_run_wrap,
@@ -71,6 +72,7 @@ class AgnoInstrumentor(BaseInstrumentor):
         """Initialize the AgnoInstrumentor."""
         super().__init__()
         self._original_thread_pool_submit = None
+        self._original_runtime_detach = None
 
     def instrumentation_dependencies(self) -> Collection[str]:
         return _instruments
@@ -91,8 +93,8 @@ class AgnoInstrumentor(BaseInstrumentor):
         except importlib.metadata.PackageNotFoundError:
             version = "unknown"
 
-        # CRITICAL: Patch ThreadPoolExecutor globally to preserve OpenTelemetry context
-        self._patch_thread_pool_executor()
+        # Patch OpenTelemetry's context detach to suppress benign errors in async/threaded scenarios
+        self._patch_otel_context_detach()
 
         # Workflow Operations (Always Instrumented)
         wrap_function_wrapper(
@@ -243,7 +245,6 @@ class AgnoInstrumentor(BaseInstrumentor):
             memory_module, memory_class = resolve_agno_memory_target()
 
             if memory_module is not None:
-
                 # Wrap memory add/search exactly once using the dedicated wrappers to avoid
                 # duplicate spans and performance overhead.
                 wrap_function_wrapper(
@@ -336,7 +337,6 @@ class AgnoInstrumentor(BaseInstrumentor):
 
                 # agno 2.x versions do not have load method
                 if hasattr(knowledge_class, "load"):
-
                     wrap_function_wrapper(
                         knowledge_module,
                         f"{knowledge_class}.load",
@@ -427,12 +427,10 @@ class AgnoInstrumentor(BaseInstrumentor):
                 ),
             )
 
-
-
             # Team Operations
 
             try:
-                from agno.team.team import Team # pylint: disable=import-error
+                from agno.team.team import Team  # pylint: disable=import-error
             except ImportError:
                 Team = None
             # agno 2.x versions do use Team._arun_stream and Team._arun methods
@@ -611,26 +609,45 @@ class AgnoInstrumentor(BaseInstrumentor):
             # CRITICAL: Parallel execution operations for context preservation
             # Note: Parallel class doesn't have a run method, context is preserved via Model.run_function_calls
 
-            wrap_function_wrapper(
-                "agno.team.team",
-                "Team._make_memories_and_summaries",
-                parallel_execution_wrap(
-                    "team._make_memories_and_summaries",
-                    version,
-                    environment,
-                    application_name,
-                    tracer,
-                    pricing_info,
-                    capture_message_content,
-                    metrics,
-                    disable_metrics,
-                ),
-            )
+            # NOTE: Team._make_memories_and_summaries method was removed in recent Agno versions
+            # Only Team._make_memories exists now. If parallel execution instrumentation is needed,
+            # it should be added for Team._make_memories instead.
 
             # NOTE: Removed duplicate reasoning tool instrumentation
             # The bridge spans from Model.run_function_call provide sufficient tracing
             # without creating redundant spans for ReasoningTools.think/analyze
 
+    def _patch_otel_context_detach(self):
+        """
+        Patch OpenTelemetry's context detach to suppress benign cross-context errors.
+
+        Agno uses ThreadPoolExecutor internally for tool execution, which can cause
+        context tokens to be detached in a different context than where they were created.
+        This is benign but OTel logs it as an error. We suppress the logging for these cases.
+        """
+        import logging
+        from opentelemetry.context import _RUNTIME_CONTEXT
+
+        # Suppress the specific logger that logs "Failed to detach context"
+        otel_context_logger = logging.getLogger("opentelemetry.context")
+        otel_context_logger.setLevel(logging.CRITICAL)
+
+        # Also patch the runtime context's detach to not raise for cross-context errors
+        original_detach = _RUNTIME_CONTEXT.detach
+
+        def patched_detach(token):
+            """Detach context token, suppressing cross-context ValueError"""
+            try:
+                original_detach(token)
+            except ValueError as e:
+                # Silently ignore "was created in a different Context" errors
+                # These occur when Agno's ThreadPoolExecutor runs tools in different threads
+                if "was created in a different Context" not in str(e):
+                    raise
+
+        _RUNTIME_CONTEXT.detach = patched_detach
+        self._original_runtime_detach = original_detach
+
     def _patch_thread_pool_executor(self):
         """
         CRITICAL: Patch ThreadPoolExecutor.submit globally to preserve OpenTelemetry context.
@@ -648,12 +665,26 @@ class AgnoInstrumentor(BaseInstrumentor):
             current_context = context_api.get_current()
 
             def context_wrapper(*wrapper_args, **wrapper_kwargs):
-                # Restore context in the thread
-                token = context_api.attach(current_context)
+                # OpenTelemetry context management for threaded execution
+                # Note: In async/threaded scenarios, the context token may become invalid
+                # if the execution context changes. We handle this gracefully.
+                token = None
+                try:
+                    token = context_api.attach(current_context)
+                except Exception:
+                    # If attach fails, continue without context propagation
+                    pass
+
                 try:
                     return func(*wrapper_args, **wrapper_kwargs)
                 finally:
-                    context_api.detach(token)
+                    if token is not None:
+                        try:
+                            context_api.detach(token)
+                        except Exception:
+                            # Silently ignore detach errors - can happen when context changes
+                            # between attach and detach in async/threaded scenarios
+                            pass
 
             return original_submit(self, context_wrapper, *args, **kwargs)
 
