@@ -16,8 +16,17 @@ from openlit.instrumentation.cohere.utils import (
 )
 from openlit.semcov import SemanticConvention
 
-def chat(version, environment, application_name,
-    tracer, pricing_info, capture_message_content, metrics, disable_metrics):
+
+def chat(
+    version,
+    environment,
+    application_name,
+    tracer,
+    pricing_info,
+    capture_message_content,
+    metrics,
+    disable_metrics,
+):
     """
     Generates a telemetry wrapper for GenAI chat function call
     """
@@ -27,7 +36,9 @@ def chat(version, environment, application_name,
         Wraps the GenAI chat function call.
         """
 
-        server_address, server_port = set_server_address_and_port(instance, "api.cohere.com", 443)
+        server_address, server_port = set_server_address_and_port(
+            instance, "api.cohere.com", 443
+        )
         request_model = kwargs.get("model", "command-r-plus-08-2024")
 
         span_name = f"{SemanticConvention.GEN_AI_OPERATION_TYPE_CHAT} {request_model}"
@@ -49,15 +60,24 @@ def chat(version, environment, application_name,
                 capture_message_content=capture_message_content,
                 disable_metrics=disable_metrics,
                 version=version,
-                **kwargs
+                **kwargs,
             )
 
         return response
 
     return wrapper
 
-def chat_stream(version, environment, application_name,
-    tracer, pricing_info, capture_message_content, metrics, disable_metrics):
+
+def chat_stream(
+    version,
+    environment,
+    application_name,
+    tracer,
+    pricing_info,
+    capture_message_content,
+    metrics,
+    disable_metrics,
+):
     """
     Generates a telemetry wrapper for GenAI chat_stream function call
     """
@@ -68,15 +88,15 @@ def chat_stream(version, environment, application_name,
         """
 
         def __init__(
-                self,
-                wrapped,
-                span,
-                span_name,
-                kwargs,
-                server_address,
-                server_port,
-                **args,
-            ):
+            self,
+            wrapped,
+            span,
+            span_name,
+            kwargs,
+            server_address,
+            server_port,
+            **args,
+        ):
             self.__wrapped__ = wrapped
             self._span = span
             self._span_name = span_name
@@ -120,7 +140,9 @@ def chat_stream(version, environment, application_name,
                 return chunk
             except StopIteration:
                 try:
-                    with tracer.start_as_current_span(self._span_name, kind= SpanKind.CLIENT) as self._span:
+                    with tracer.start_as_current_span(
+                        self._span_name, kind=SpanKind.CLIENT
+                    ) as self._span:
                         process_streaming_chat_response(
                             self,
                             pricing_info=pricing_info,
@@ -129,7 +151,7 @@ def chat_stream(version, environment, application_name,
                             metrics=metrics,
                             capture_message_content=capture_message_content,
                             disable_metrics=disable_metrics,
-                            version=version
+                            version=version,
                         )
 
                 except Exception as e:
@@ -142,7 +164,9 @@ def chat_stream(version, environment, application_name,
         Wraps the GenAI chat_stream function call.
         """
 
-        server_address, server_port = set_server_address_and_port(instance, "api.cohere.com", 443)
+        server_address, server_port = set_server_address_and_port(
+            instance, "api.cohere.com", 443
+        )
         request_model = kwargs.get("model", "command-r-plus-08-2024")
 
         span_name = f"{SemanticConvention.GEN_AI_OPERATION_TYPE_CHAT} {request_model}"
@@ -151,12 +175,23 @@ def chat_stream(version, environment, application_name,
         awaited_wrapped = wrapped(*args, **kwargs)
         span = tracer.start_span(span_name, kind=SpanKind.CLIENT)
 
-        return TracedSyncStream(awaited_wrapped, span, span_name, kwargs, server_address, server_port)
+        return TracedSyncStream(
+            awaited_wrapped, span, span_name, kwargs, server_address, server_port
+        )
 
     return wrapper
 
-def embed(version, environment, application_name,
-    tracer, pricing_info, capture_message_content, metrics, disable_metrics):
+
+def embed(
+    version,
+    environment,
+    application_name,
+    tracer,
+    pricing_info,
+    capture_message_content,
+    metrics,
+    disable_metrics,
+):
     """
     Generates a telemetry wrapper for GenAI embedding function call
     """
@@ -166,10 +201,14 @@ def embed(version, environment, application_name,
         Wraps the GenAI embedding function call.
         """
 
-        server_address, server_port = set_server_address_and_port(instance, "api.cohere.com", 443)
+        server_address, server_port = set_server_address_and_port(
+            instance, "api.cohere.com", 443
+        )
         request_model = kwargs.get("model", "embed-english-v3.0")
 
-        span_name = f"{SemanticConvention.GEN_AI_OPERATION_TYPE_EMBEDDING} {request_model}"
+        span_name = (
+            f"{SemanticConvention.GEN_AI_OPERATION_TYPE_EMBEDDING} {request_model}"
+        )
 
         with tracer.start_as_current_span(span_name, kind=SpanKind.CLIENT) as span:
             start_time = time.time()
@@ -190,7 +229,7 @@ def embed(version, environment, application_name,
                     capture_message_content=capture_message_content,
                     disable_metrics=disable_metrics,
                     version=version,
-                    **kwargs
+                    **kwargs,
                 )
 
             except Exception as e:
