@@ -5,15 +5,29 @@ Module for monitoring controlflow.
 
 import logging
 from opentelemetry.trace import SpanKind, Status, StatusCode
-from opentelemetry.sdk.resources import SERVICE_NAME, TELEMETRY_SDK_NAME, DEPLOYMENT_ENVIRONMENT
+from opentelemetry.sdk.resources import (
+    SERVICE_NAME,
+    TELEMETRY_SDK_NAME,
+    DEPLOYMENT_ENVIRONMENT,
+)
 from openlit.__helpers import handle_exception
 from openlit.semcov import SemanticConvention
 
 # Initialize logger for logging potential issues and operations
 logger = logging.getLogger(__name__)
 
-def wrap_controlflow(gen_ai_endpoint, version, environment, application_name,
-                 tracer, pricing_info, capture_message_content, metrics, disable_metrics):
+
+def wrap_controlflow(
+    gen_ai_endpoint,
+    version,
+    environment,
+    application_name,
+    tracer,
+    pricing_info,
+    capture_message_content,
+    metrics,
+    disable_metrics,
+):
     """
     Creates a wrapper around a function call to trace and log its execution metrics.
 
@@ -55,48 +69,67 @@ def wrap_controlflow(gen_ai_endpoint, version, environment, application_name,
         errors are handled and logged appropriately.
         """
 
-        with tracer.start_as_current_span(gen_ai_endpoint, kind= SpanKind.CLIENT) as span:
+        with tracer.start_as_current_span(
+            gen_ai_endpoint, kind=SpanKind.CLIENT
+        ) as span:
             response = wrapped(*args, **kwargs)
 
             try:
                 span.set_attribute(TELEMETRY_SDK_NAME, "openlit")
-                span.set_attribute(SemanticConvention.GEN_AI_ENDPOINT,
-                                   gen_ai_endpoint)
-                span.set_attribute(SemanticConvention.GEN_AI_SYSTEM,
-                                   SemanticConvention.GEN_AI_SYSTEM_CONTROLFLOW)
-                span.set_attribute(DEPLOYMENT_ENVIRONMENT,
-                                   environment)
-                span.set_attribute(SERVICE_NAME,
-                                   application_name)
-                span.set_attribute(SemanticConvention.GEN_AI_OPERATION,
-                                   SemanticConvention.GEN_AI_OPERATION_TYPE_AGENT)
+                span.set_attribute(SemanticConvention.GEN_AI_ENDPOINT, gen_ai_endpoint)
+                span.set_attribute(
+                    SemanticConvention.GEN_AI_SYSTEM,
+                    SemanticConvention.GEN_AI_SYSTEM_CONTROLFLOW,
+                )
+                span.set_attribute(DEPLOYMENT_ENVIRONMENT, environment)
+                span.set_attribute(SERVICE_NAME, application_name)
+                span.set_attribute(
+                    SemanticConvention.GEN_AI_OPERATION,
+                    SemanticConvention.GEN_AI_OPERATION_TYPE_AGENT,
+                )
 
                 if gen_ai_endpoint == "controlflow.create_agent":
-                    span.set_attribute(SemanticConvention.GEN_AI_AGENT_ROLE,
-                                    instance.name)
-                    span.set_attribute(SemanticConvention.GEN_AI_AGENT_INSTRUCTIONS,
-                                    kwargs.get("instructions", ""))
-                    span.set_attribute(SemanticConvention.GEN_AI_AGENT_TOOLS,
-                                    str(kwargs.get("tools", "")))
+                    span.set_attribute(
+                        SemanticConvention.GEN_AI_AGENT_ROLE, instance.name
+                    )
+                    span.set_attribute(
+                        SemanticConvention.GEN_AI_AGENT_INSTRUCTIONS,
+                        kwargs.get("instructions", ""),
+                    )
+                    span.set_attribute(
+                        SemanticConvention.GEN_AI_AGENT_TOOLS,
+                        str(kwargs.get("tools", "")),
+                    )
 
                     try:
-                        span.set_attribute(SemanticConvention.GEN_AI_REQUEST_MODEL,
-                                        instance.model.model_name)
+                        span.set_attribute(
+                            SemanticConvention.GEN_AI_REQUEST_MODEL,
+                            instance.model.model_name,
+                        )
                     except:
-                        span.set_attribute(SemanticConvention.GEN_AI_REQUEST_MODEL,
-                                        kwargs.get("model", "openai/gpt-4o-mini"))
+                        span.set_attribute(
+                            SemanticConvention.GEN_AI_REQUEST_MODEL,
+                            kwargs.get("model", "openai/gpt-4o-mini"),
+                        )
 
                 elif gen_ai_endpoint == "controlflow.create_task":
-                    if kwargs.get("objective","") == "":
-                        span.set_attribute(SemanticConvention.GEN_AI_AGENT_GOAL,
-                                           str(args[0]))
+                    if kwargs.get("objective", "") == "":
+                        span.set_attribute(
+                            SemanticConvention.GEN_AI_AGENT_GOAL, str(args[0])
+                        )
                     else:
-                        span.set_attribute(SemanticConvention.GEN_AI_AGENT_GOAL,
-                                           kwargs.get("objective",""))
-                    span.set_attribute(SemanticConvention.GEN_AI_AGENT_INSTRUCTIONS,
-                                       kwargs.get("instructions", ""))
-                    span.set_attribute(SemanticConvention.GEN_AI_AGENT_CONTEXT,
-                                       str(kwargs.get("context", "")))
+                        span.set_attribute(
+                            SemanticConvention.GEN_AI_AGENT_GOAL,
+                            kwargs.get("objective", ""),
+                        )
+                    span.set_attribute(
+                        SemanticConvention.GEN_AI_AGENT_INSTRUCTIONS,
+                        kwargs.get("instructions", ""),
+                    )
+                    span.set_attribute(
+                        SemanticConvention.GEN_AI_AGENT_CONTEXT,
+                        str(kwargs.get("context", "")),
+                    )
 
                 span.set_status(Status(StatusCode.OK))
 
