@@ -192,16 +192,30 @@ def common_chat_logic(
 
     # Span Attributes for Tools
     if scope._tools is not None:
-        scope._span.set_attribute(
-            SemanticConvention.GEN_AI_TOOL_NAME, scope._tools.get("function", "")
-        ).get("name", "")
-        scope._span.set_attribute(
-            SemanticConvention.GEN_AI_TOOL_CALL_ID, str(scope._tools.get("id", ""))
-        )
-        scope._span.set_attribute(
-            SemanticConvention.GEN_AI_TOOL_ARGS,
-            str(scope._tools.get("function", "").get("arguments", "")),
-        )
+        if isinstance(scope._tools, dict):
+            scope._span.set_attribute(
+                SemanticConvention.GEN_AI_TOOL_NAME, scope._tools.get("function", "")
+            ).get("name", "")
+            scope._span.set_attribute(
+                SemanticConvention.GEN_AI_TOOL_CALL_ID, str(scope._tools.get("id", ""))
+            )
+            scope._span.set_attribute(
+                SemanticConvention.GEN_AI_TOOL_ARGS,
+                str(scope._tools.get("function", "").get("arguments", "")),
+            )
+        elif isinstance(scope._tools, list) and len(scope._tools) > 0:
+            for tool in scope._tools:
+                scope._span.set_attribute(
+                    SemanticConvention.GEN_AI_TOOL_NAME,
+                    tool.get("function", {}).get("name", ""),
+                )
+                scope._span.set_attribute(
+                    SemanticConvention.GEN_AI_TOOL_CALL_ID, str(tool.get("id", ""))
+                )
+                scope._span.set_attribute(
+                    SemanticConvention.GEN_AI_TOOL_ARGS,
+                    str(tool.get("function", {}).get("arguments", "")),
+                )
 
     # Span Attributes for Content
     if capture_message_content:
@@ -248,6 +262,160 @@ def common_chat_logic(
         )
 
 
+def common_generate_logic(
+    scope,
+    gen_ai_endpoint,
+    pricing_info,
+    environment,
+    application_name,
+    metrics,
+    capture_message_content,
+    disable_metrics,
+    version,
+):
+    """
+    Process generate request and generate Telemetry
+    """
+
+    scope._end_time = time.monotonic()
+    if len(scope._timestamps) > 1:
+        scope._tbt = calculate_tbt(scope._timestamps)
+    json_body = scope._kwargs.get("json", {}) or {}
+    prompt = json_body.get("prompt")
+    request_model = json_body.get("model") or scope._kwargs.get("model", "llama3.2")
+    is_stream = scope._kwargs.get("stream", False)
+
+    cost = get_chat_model_cost(
+        request_model, pricing_info, scope._input_tokens, scope._output_tokens
+    )
+
+    # Common Span Attributes
+    common_span_attributes(
+        scope,
+        SemanticConvention.GEN_AI_OPERATION_TYPE_TEXT_COMPLETION,
+        SemanticConvention.GEN_AI_SYSTEM_OLLAMA,
+        scope._server_address,
+        scope._server_port,
+        request_model,
+        request_model,
+        environment,
+        application_name,
+        is_stream,
+        scope._tbt,
+        scope._ttft,
+        version,
+    )
+
+    # Span Attributes for Request parameters
+    options = json_body.get("options", scope._kwargs.get("options", {}))
+    attributes = [
+        (SemanticConvention.GEN_AI_REQUEST_FREQUENCY_PENALTY, "repeat_penalty"),
+        (SemanticConvention.GEN_AI_REQUEST_MAX_TOKENS, "max_tokens"),
+        (SemanticConvention.GEN_AI_REQUEST_SEED, "seed"),
+        (SemanticConvention.GEN_AI_REQUEST_STOP_SEQUENCES, "stop"),
+        (SemanticConvention.GEN_AI_REQUEST_TEMPERATURE, "temperature"),
+        (SemanticConvention.GEN_AI_REQUEST_TOP_P, "top_p"),
+        (SemanticConvention.GEN_AI_REQUEST_TOP_K, "top_k"),
+    ]
+    for attribute, key in attributes:
+        value = options.get(key)
+        if value is not None:
+            scope._span.set_attribute(attribute, value)
+
+    # Span Attributes for Response parameters
+    scope._span.set_attribute(
+        SemanticConvention.GEN_AI_RESPONSE_FINISH_REASON, [scope._finish_reason]
+    )
+    scope._span.set_attribute(
+        SemanticConvention.GEN_AI_OUTPUT_TYPE,
+        "text" if isinstance(scope._llmresponse, str) else "json",
+    )
+
+    # Span Attributes for Cost and Tokens
+    scope._span.set_attribute(
+        SemanticConvention.GEN_AI_USAGE_INPUT_TOKENS, scope._input_tokens
+    )
+    scope._span.set_attribute(
+        SemanticConvention.GEN_AI_USAGE_OUTPUT_TOKENS, scope._output_tokens
+    )
+    scope._span.set_attribute(
+        SemanticConvention.GEN_AI_CLIENT_TOKEN_USAGE,
+        scope._input_tokens + scope._output_tokens,
+    )
+    scope._span.set_attribute(SemanticConvention.GEN_AI_USAGE_COST, cost)
+
+    # Span Attributes for Tools
+    if scope._tools is not None:
+        if isinstance(scope._tools, dict):
+            scope._span.set_attribute(
+                SemanticConvention.GEN_AI_TOOL_NAME, scope._tools.get("function", "")
+            ).get("name", "")
+            scope._span.set_attribute(
+                SemanticConvention.GEN_AI_TOOL_CALL_ID, str(scope._tools.get("id", ""))
+            )
+            scope._span.set_attribute(
+                SemanticConvention.GEN_AI_TOOL_ARGS,
+                str(scope._tools.get("function", "").get("arguments", "")),
+            )
+        elif isinstance(scope._tools, list) and len(scope._tools) > 0:
+            for tool in scope._tools:
+                scope._span.set_attribute(
+                    SemanticConvention.GEN_AI_TOOL_NAME,
+                    tool.get("function", {}).get("name", ""),
+                )
+                scope._span.set_attribute(
+                    SemanticConvention.GEN_AI_TOOL_CALL_ID, str(tool.get("id", ""))
+                )
+                scope._span.set_attribute(
+                    SemanticConvention.GEN_AI_TOOL_ARGS,
+                    str(tool.get("function", {}).get("arguments", "")),
+                )
+
+    # Span Attributes for Content
+    if capture_message_content:
+        scope._span.set_attribute(SemanticConvention.GEN_AI_CONTENT_PROMPT, prompt)
+        scope._span.set_attribute(
+            SemanticConvention.GEN_AI_CONTENT_COMPLETION, scope._llmresponse
+        )
+
+        # To be removed once the change to span_attributes (from span events) is complete
+        scope._span.add_event(
+            name=SemanticConvention.GEN_AI_CONTENT_PROMPT_EVENT,
+            attributes={
+                SemanticConvention.GEN_AI_CONTENT_PROMPT: prompt,
+            },
+        )
+        scope._span.add_event(
+            name=SemanticConvention.GEN_AI_CONTENT_COMPLETION_EVENT,
+            attributes={
+                SemanticConvention.GEN_AI_CONTENT_COMPLETION: scope._llmresponse,
+            },
+        )
+
+    scope._span.set_status(Status(StatusCode.OK))
+
+    # Metrics
+    if not disable_metrics:
+        record_completion_metrics(
+            metrics,
+            SemanticConvention.GEN_AI_OPERATION_TYPE_TEXT_COMPLETION,
+            SemanticConvention.GEN_AI_SYSTEM_OLLAMA,
+            scope._server_address,
+            scope._server_port,
+            request_model,
+            scope._response_model,
+            environment,
+            application_name,
+            scope._start_time,
+            scope._end_time,
+            cost,
+            scope._input_tokens,
+            scope._output_tokens,
+            scope._tbt,
+            scope._ttft,
+        )
+
+
 def common_embedding_logic(
     scope,
     gen_ai_endpoint,
@@ -409,6 +577,91 @@ def process_chat_response(
     return response
 
 
+def process_streaming_generate_response(
+    self,
+    pricing_info,
+    environment,
+    application_name,
+    metrics,
+    capture_message_content=False,
+    disable_metrics=False,
+    version="",
+):
+    """
+    Process streaming generate request and generate Telemetry
+    """
+
+    common_generate_logic(
+        self,
+        "ollama.generate",
+        pricing_info,
+        environment,
+        application_name,
+        metrics,
+        capture_message_content,
+        disable_metrics,
+        version,
+    )
+
+
+def process_generate_response(
+    response,
+    gen_ai_endpoint,
+    pricing_info,
+    server_port,
+    server_address,
+    environment,
+    application_name,
+    metrics,
+    start_time,
+    span,
+    capture_message_content=False,
+    disable_metrics=False,
+    version="1.0.0",
+    **kwargs,
+):
+    """
+    Process generate request and generate Telemetry
+    """
+
+    scope = type("GenericScope", (), {})()
+    response_dict = response_as_dict(response)
+
+    scope._start_time = start_time
+    scope._end_time = time.monotonic()
+    scope._span = span
+    scope._llmresponse = response_dict.get("response", "")
+    scope._response_role = response_dict.get("message", {}).get("role", "assistant")
+    scope._input_tokens = response_dict.get("prompt_eval_count", 0)
+    scope._output_tokens = response_dict.get("eval_count", 0)
+    scope._response_model = response_dict.get("model", "llama3.2")
+    scope._finish_reason = response_dict.get("done_reason", "")
+    scope._timestamps = []
+    scope._ttft = scope._end_time - scope._start_time
+    scope._tbt = 0
+    scope._server_address, scope._server_port = server_address, server_port
+    scope._kwargs = kwargs
+
+    if scope._kwargs.get("tools"):
+        scope._tools = response_dict.get("choices")[0].get("message").get("tool_calls")
+    else:
+        scope._tools = None
+
+    common_generate_logic(
+        scope,
+        gen_ai_endpoint,
+        pricing_info,
+        environment,
+        application_name,
+        metrics,
+        capture_message_content,
+        disable_metrics,
+        version,
+    )
+
+    return response
+
+
 def process_embedding_response(
     response,
     gen_ai_endpoint,
